@@ -6,12 +6,13 @@ import pystencils as ps
 from lbmpy.advanced_streaming import *
 from lbmpy.boundaries import *
 from lbmpy.creationfunctions import *
+from lbmpy.enums import *
 from lbmpy.geometry import *
 from lbmpy.lbstep import LatticeBoltzmannStep
 from lbmpy.macroscopic_value_kernels import pdf_initialization_assignments
 from lbmpy.parameterization import ScalingWidget
 from lbmpy.postprocessing import *
 from lbmpy.scenarios import *
-from lbmpy.stencils import get_stencil
+from lbmpy.stencils import get_stencil, LBStencil
 from pystencils import make_slice, show_code
 from pystencils.jupyter import *
